==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-ci/xl-react-dip-ci.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';

import {isComponentDisabled, getModelValue} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';

import {XlReactDipContainerProps} from '../xl-react-dip-props';
import {XlReactDipCiComponent} from './xl-react-dip-ci-component';

export class XlReactDipCi extends Component {
    static propTypes = {
        className: PropTypes.string,
        controlClassName: PropTypes.string,
        handlers: PropTypes.object,
        model: PropTypes.string,
        objLabel: PropTypes.string,
        showSearchIcon: PropTypes.bool,
        toggleButton: PropTypes.node,
        ...XlReactDipContainerProps
    };

    static defaultProps = {displayMode: 'edit', metadata: {}, objLabel: 'id', validators: []};

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', '');
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    onWidgetModelChange = (model, initial) => {
        computeNextState(this, this.props, getValidators(this.props), model, {pristine: initial});
    };

    messageHandler = (message) => {
        this.setState({message});
    };

    render() {
        const {
            className,
            controlClassName,
            handlers,
            metadata,
            objLabel,
            onMessageChange,
            onPristinityChange,
            onValidityChange,
            register,
            toggleButton,
            showSearchIcon
        } = this.props;
        const {message, model} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactDipCiComponent {...({
            className,
            controlClassName,
            disabled,
            handlers,
            message,
            messageHandler: this.messageHandler,
            metadata,
            model,
            objLabel,
            onMessageChange,
            onModelChange: this.onWidgetModelChange,
            onPristinityChange,
            onValidityChange,
            register,
            showSearchIcon,
            toggleButton
        })}
        />;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-ci/xl-react-dip-ci.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';

import {isComponentDisabled} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';

import {XlReactDipContainerProps} from '../xl-react-dip-props';
import RU from '../../utils/ramda-utils';
import {XlReactDipCiComponent} from './xl-react-dip-ci-component';

export class XlReactDipCi extends Component {
    static propTypes = {
        className: PropTypes.string,
        controlClassName: PropTypes.string,
        handlers: PropTypes.object,
        model: PropTypes.string,
        objLabel: PropTypes.string,
        showSearchIcon: PropTypes.bool,
        toggleButton: PropTypes.node,
        ...XlReactDipContainerProps
    };

    static defaultProps = {displayMode: 'edit', metadata: {}, objLabel: 'id', validators: []};

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        computeInitialState(this, this.props, getValidators(this.props), this.props.model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    componentWillUnmount() {
        RU.invoke('unregister', [], this.props);
    }

    onWidgetModelChange = (model, initial) => {
        computeNextState(this, this.props, getValidators(this.props), model, {pristine: initial});
    };

    messageHandler = (message) => {
        this.setState({message});
    };

    render() {
        const {
            className,
            controlClassName,
            handlers,
            metadata,
            objLabel,
            onMessageChange,
            onPristinityChange,
            onValidityChange,
            register,
            toggleButton,
            showSearchIcon
        } = this.props;
        const {message, model} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactDipCiComponent {...({
            className,
            controlClassName,
            disabled,
            handlers,
            message,
            messageHandler: this.messageHandler,
            metadata,
            model,
            objLabel,
            onMessageChange,
            onModelChange: this.onWidgetModelChange,
            onPristinityChange,
            onValidityChange,
            register,
            showSearchIcon,
            toggleButton
        })}
        />;
    }
}
